@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
 """Tests for tmuxp.
 
 tmuxp.tests
 ~~~~~~~~~~~
 
 """
-from __future__ import absolute_import, unicode_literals
-
 import os
 
 current_dir = os.path.abspath(os.path.dirname(__file__))
