@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
 """Test for tmuxp command line interface."""
-from __future__ import absolute_import
-
 import json
 import os
 
@@ -15,16 +12,15 @@ import pytest
 import click
 import kaptan
 from click.testing import CliRunner
-from tmuxp_test_plugin_bwb.plugin import PluginBeforeWorkspaceBuilder
 
 import libtmux
 from libtmux.common import has_lt_version
 from libtmux.exc import LibTmuxException
 from tmuxp import cli, config, exc
 from tmuxp.cli import (
-    _reattach,
-    _load_attached,
     _load_append_windows_to_current_session,
+    _load_attached,
+    _reattach,
     command_debug_info,
     command_ls,
     get_config_dir,
@@ -149,6 +145,8 @@ def test_tmuxp_configdir_xdg_config_dir(tmpdir, monkeypatch):
 
 def test_resolve_dot(tmpdir, homedir, configdir, projectdir, monkeypatch):
     monkeypatch.setenv('HOME', str(homedir))
+    monkeypatch.setenv("XDG_CONFIG_HOME", str(homedir.join('.config')))
+
     projectdir.join('.tmuxp.yaml').ensure()
     user_config_name = 'myconfig'
     user_config = configdir.join('%s.yaml' % user_config_name).ensure()
@@ -967,6 +965,7 @@ def test_pass_config_dir_ClickPath(tmpdir):
 
 def test_ls_cli(monkeypatch, tmpdir):
     monkeypatch.setenv("HOME", str(tmpdir))
+    monkeypatch.setenv("XDG_CONFIG_HOME", str(tmpdir.join('.config')))
 
     filenames = [
         '.git/',
@@ -995,7 +994,9 @@ def test_ls_cli(monkeypatch, tmpdir):
     assert cli_output == '\n'.join(stems) + '\n'
 
 
-def test_load_plugins():
+def test_load_plugins(monkeypatch_plugin_test_packages):
+    from tmuxp_test_plugin_bwb.plugin import PluginBeforeWorkspaceBuilder
+
     plugins_config = loadfixture("workspacebuilder/plugin_bwb.yaml")
 
     sconfig = kaptan.Kaptan(handler='yaml')
@@ -1023,7 +1024,9 @@ def test_load_plugins():
         )
     ],
 )
-def test_load_plugins_version_fail_skip(cli_args, inputs):
+def test_load_plugins_version_fail_skip(
+    monkeypatch_plugin_test_packages, cli_args, inputs
+):
     runner = CliRunner()
 
     results = runner.invoke(cli.cli, cli_args, input=''.join(inputs))
@@ -1039,7 +1042,9 @@ def test_load_plugins_version_fail_skip(cli_args, inputs):
         )
     ],
 )
-def test_load_plugins_version_fail_no_skip(cli_args, inputs):
+def test_load_plugins_version_fail_no_skip(
+    monkeypatch_plugin_test_packages, cli_args, inputs
+):
     runner = CliRunner()
 
     results = runner.invoke(cli.cli, cli_args, input=''.join(inputs))
@@ -1049,14 +1054,16 @@ def test_load_plugins_version_fail_no_skip(cli_args, inputs):
 @pytest.mark.parametrize(
     "cli_args", [(['load', 'tests/fixtures/workspacebuilder/plugin_missing_fail.yaml'])]
 )
-def test_load_plugins_plugin_missing(cli_args):
+def test_load_plugins_plugin_missing(monkeypatch_plugin_test_packages, cli_args):
     runner = CliRunner()
 
     results = runner.invoke(cli.cli, cli_args)
     assert '[Plugin Error]' in results.output
 
 
-def test_plugin_system_before_script(server, monkeypatch):
+def test_plugin_system_before_script(
+    monkeypatch_plugin_test_packages, server, monkeypatch
+):
     # this is an implementation test. Since this testsuite may be ran within
     # a tmux session by the developer himself, delete the TMUX variable
     # temporarily.
@@ -1072,7 +1079,7 @@ def test_plugin_system_before_script(server, monkeypatch):
     assert session.name == 'plugin_test_bs'
 
 
-def test_reattach_plugins(server):
+def test_reattach_plugins(monkeypatch_plugin_test_packages, server):
     config_plugins = loadfixture("workspacebuilder/plugin_r.yaml")
 
     sconfig = kaptan.Kaptan(handler='yaml')
@@ -1174,6 +1181,7 @@ def test_load_attached_within_tmux_detached(server, monkeypatch):
 
     assert builder.session.switch_client.call_count == 1
 
+
 def test_load_append_windows_to_current_session(server, monkeypatch):
     yaml_config = loadfixture("workspacebuilder/two_pane.yaml")
     sconfig = kaptan.Kaptan(handler='yaml')
@@ -1195,7 +1203,6 @@ def test_load_append_windows_to_current_session(server, monkeypatch):
     assert len(server._list_windows()) == 6
 
 
-
 def test_debug_info_cli(monkeypatch, tmpdir):
     monkeypatch.setenv('SHELL', '/bin/bash')
 
