@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
 """Test for tmuxp plugin api."""
-from __future__ import absolute_import
-
 import pytest
 
 from tmuxp.exc import TmuxpPluginException
@@ -24,6 +21,11 @@ from .fixtures.pluginsystem.partials.tmuxp_version_fail import (
 )
 
 
+@pytest.fixture(autouse=True)
+def autopatch_sitedir(monkeypatch_plugin_test_packages):
+    pass
+
+
 def test_all_pass():
     AllVersionPassPlugin()
 
